aboutsummaryrefslogtreecommitdiffstats
path: root/phpBB
diff options
context:
space:
mode:
authorbrunoais <brunoaiss@gmail.com>2014-12-03 14:00:00 +0000
committerbrunoais <brunoaiss@gmail.com>2014-12-03 14:00:00 +0000
commit10a4f791358deb5e4365a74ca56982b36771b603 (patch)
tree6ec824c98d38f8cc2d91e17809a79bef87e4e0cc /phpBB
parent4159bb1340cc0e6998196372af56deb7226b93d6 (diff)
downloadforums-10a4f791358deb5e4365a74ca56982b36771b603.tar
forums-10a4f791358deb5e4365a74ca56982b36771b603.tar.gz
forums-10a4f791358deb5e4365a74ca56982b36771b603.tar.bz2
forums-10a4f791358deb5e4365a74ca56982b36771b603.tar.xz
forums-10a4f791358deb5e4365a74ca56982b36771b603.zip
[ticket/13146] Fixed variable name for the override
PHPBB3-13146
Diffstat (limited to 'phpBB')
-rw-r--r--phpBB/phpbb/content_visibility.php10
1 files changed, 5 insertions, 5 deletions
diff --git a/phpBB/phpbb/content_visibility.php b/phpBB/phpbb/content_visibility.php
index 655e76a4a8..2121bd8305 100644
--- a/phpBB/phpbb/content_visibility.php
+++ b/phpBB/phpbb/content_visibility.php
@@ -168,7 +168,7 @@ class content_visibility
$approve_forums = array_intersect($forum_ids, array_keys($this->auth->acl_getf('m_approve', true)));
- $content_replaced = false;
+ $get_forums_visibility_sql_overwrite = false;
/**
* Allow changing the result of calling get_forums_visibility_sql
*
@@ -178,7 +178,7 @@ class content_visibility
* @var array forum_ids Array of forum ids which the posts/topics are limited to
* @var string table_alias Table alias to prefix in SQL queries
* @var array approve_forums Array of forums where the user has m_approve permissions
* @var bool content_replaced Forces the function to return where_sql after executing the event
* @since 3.1.3-RC1
*/
$vars = array(
@@ -187,13 +187,13 @@ class content_visibility
'forum_ids',
'table_alias',
'approve_forums',
- 'content_replaced',
+ 'get_forums_visibility_sql_overwrite',
);
extract($this->phpbb_dispatcher->trigger_event('core.phpbb_content_visibility_get_forums_visibility_before', compact($vars)));
- if ($content_replaced)
+ if ($get_forums_visibility_sql_overwrite)
{
- return $content_replaced;
+ return $get_forums_visibility_sql_overwrite;
}
@@ -178,7 +178,7 @@ class content_visibility
* @var string table_alias Table alias to prefix in SQL queries
* @var array approve_forums Array of forums where the user has m_approve permissions
- * @var bool content_replaced Forces the function to return where_sql after executing the event
+ * @var bool get_forums_visibility_sql_overwrite Forces the function to return where_sql after executing the event
* @since 3.1.3-RC1
*/